@@ -1,6 +1,7 @@
 test_that("temporal plot is returned in the correct format", {
   expect_type(peak_temporal_plots, "list")
-  expect_equal(class(peak_temporal_plots$Baseline), c("gg", "ggplot"))
+  expect_true(any(inherits(peak_temporal_plots$Baseline, c("ggplot", "gg"))))
+  #expect_equal(class(peak_temporal_plots$Baseline), c("gg", "ggplot"))
   # one plot per scenario
   expect_equal(length(peak_temporal_plots), length(psa_data))
 })
